==> sumus-6.3.3-sources.jar: io/intino/sumus/graph/Distribution.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Distribution extends io.intino.sumus.graph.DataRetriever implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {

	protected java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList = new java.util.ArrayList<>();

	public Distribution(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList() {
		return java.util.Collections.unmodifiableList(sourceList);
	}

	public io.intino.sumus.graph.Distribution.Source source(int index) {
		return sourceList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList(java.util.function.Predicate<io.intino.sumus.graph.Distribution.Source> predicate) {
		return sourceList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(sourceList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Distribution$Source")) this.sourceList.add(node.as(io.intino.sumus.graph.Distribution.Source.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Distribution$Source")) this.sourceList.remove(node.as(io.intino.sumus.graph.Distribution.Source.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.DataRetriever.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Distribution.Source source(io.intino.sumus.graph.Cube.Property property) {
		    io.intino.sumus.graph.Distribution.Source newElement = core$().graph().concept(io.intino.sumus.graph.Distribution.Source.class).createNode(name, core$()).as(io.intino.sumus.graph.Distribution.Source.class);
			newElement.core$().set(newElement, "property", java.util.Collections.singletonList(property));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void source(java.util.function.Predicate<io.intino.sumus.graph.Distribution.Source> filter) {
			new java.util.ArrayList<>(sourceList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Source extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Cube.Property property;

		public Source(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Cube.Property property() {
			return property;
		}

		public Source property(io.intino.sumus.graph.Cube.Property value) {
			this.property = value;
			return (Source) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("property", this.property != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.property)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("property")) this.property = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Cube.Property.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("property")) this.property = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Cube.Property.class) : null;
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}

==> sumus-7.0.3-sources.jar: io/intino/sumus/graph/Distribution.java <==
package io.intino.sumus.graph;

import io.intino.sumus.graph.*;


public class Distribution extends io.intino.sumus.graph.DataRetriever implements io.intino.tara.magritte.tags.Component, io.intino.tara.magritte.tags.Terminal {

	protected java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList = new java.util.ArrayList<>();

	public Distribution(io.intino.tara.magritte.Node node) {
		super(node);
	}

	public java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList() {
		return java.util.Collections.unmodifiableList(sourceList);
	}

	public io.intino.sumus.graph.Distribution.Source source(int index) {
		return sourceList.get(index);
	}

	public java.util.List<io.intino.sumus.graph.Distribution.Source> sourceList(java.util.function.Predicate<io.intino.sumus.graph.Distribution.Source> predicate) {
		return sourceList().stream().filter(predicate).collect(java.util.stream.Collectors.toList());
	}



	protected java.util.List<io.intino.tara.magritte.Node> componentList$() {
		java.util.Set<io.intino.tara.magritte.Node> components = new java.util.LinkedHashSet<>(super.componentList$());
		new java.util.ArrayList<>(sourceList).forEach(c -> components.add(c.core$()));
		return new java.util.ArrayList<>(components);
	}

	@Override
	protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
		java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>(super.variables$());

		return map;
	}

	@Override
	protected void addNode$(io.intino.tara.magritte.Node node) {
		super.addNode$(node);
		if (node.is("Distribution$Source")) this.sourceList.add(node.as(io.intino.sumus.graph.Distribution.Source.class));
	}

	@Override
    protected void removeNode$(io.intino.tara.magritte.Node node) {
        super.removeNode$(node);
        if (node.is("Distribution$Source")) this.sourceList.remove(node.as(io.intino.sumus.graph.Distribution.Source.class));
    }

	@Override
	protected void load$(java.lang.String name, java.util.List<?> values) {
		super.load$(name, values);
	}

	@Override
	protected void set$(java.lang.String name, java.util.List<?> values) {
		super.set$(name, values);
	}

	public Create create() {
		return new Create(null);
	}

	public Create create(java.lang.String name) {
		return new Create(name);
	}

	public class Create extends io.intino.sumus.graph.DataRetriever.Create {


		public Create(java.lang.String name) {
			super(name);
		}

		public io.intino.sumus.graph.Distribution.Source source(io.intino.sumus.graph.Cube.Property property) {
		    io.intino.sumus.graph.Distribution.Source newElement = core$().graph().concept(io.intino.sumus.graph.Distribution.Source.class).createNode(this.name, core$()).as(io.intino.sumus.graph.Distribution.Source.class);
			newElement.core$().set(newElement, "property", java.util.Collections.singletonList(property));
		    return newElement;
		}

	}

	public Clear clear() {
		return new Clear();
	}

	public class Clear  {
		public void source(java.util.function.Predicate<io.intino.sumus.graph.Distribution.Source> filter) {
			new java.util.ArrayList<>(sourceList()).stream().filter(filter).forEach(io.intino.tara.magritte.Layer::delete$);
		}
	}

	public static class Source extends io.intino.tara.magritte.Layer implements io.intino.tara.magritte.tags.Terminal {
		protected io.intino.sumus.graph.Cube.Property property;

		public Source(io.intino.tara.magritte.Node node) {
			super(node);
		}

		public io.intino.sumus.graph.Cube.Property property() {
			return property;
		}

		public Source property(io.intino.sumus.graph.Cube.Property value) {
			this.property = value;
			return (Source) this;
		}

		@Override
		protected java.util.Map<java.lang.String, java.util.List<?>> variables$() {
			java.util.Map<String, java.util.List<?>> map = new java.util.LinkedHashMap<>();
			map.put("property", this.property != null ? new java.util.ArrayList(java.util.Collections.singletonList(this.property)) : java.util.Collections.emptyList());
			return map;
		}

		@Override
		protected void load$(java.lang.String name, java.util.List<?> values) {
			super.load$(name, values);
			if (name.equalsIgnoreCase("property")) this.property = io.intino.tara.magritte.loaders.NodeLoader.load(values, io.intino.sumus.graph.Cube.Property.class, this).get(0);
		}

		@Override
		protected void set$(java.lang.String name, java.util.List<?> values) {
			super.set$(name, values);
			if (name.equalsIgnoreCase("property")) this.property = values.get(0)!= null ? core$().graph().load(((io.intino.tara.magritte.Layer) values.get(0)).core$().id()).as(io.intino.sumus.graph.Cube.Property.class) : null;
		}


		public io.intino.sumus.graph.SumusGraph graph() {
			return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
		}
	}


	public io.intino.sumus.graph.SumusGraph graph() {
		return (io.intino.sumus.graph.SumusGraph) core$().graph().as(io.intino.sumus.graph.SumusGraph.class);
	}
}
